==> fengoffice_1.7.5.zip: fengoffice/language/es_la/emails.php <==
<?php return array(
	'new message' => 'Nueva nota',
	'new comment' => 'Nuevo comentario',
	'your account created' => 'Su nueva cuenta en Feng Office ha sido creada',
	'your password' => 'Contraseña',
	'milestone assigned to you' => 'Se le ha asignado un hito',
	'task assigned to you' => 'Se le ha asignado una tarea',
	'hi john doe' => 'Hola {0}',	
	'user password reseted' => 'Su contraseña ha sido cambiada. Su nueva contraseña es \'{0}\'.',
	'password expiration reminder' => 'Recordatorio de expiración de contraseña',
	'password expires days' => 'Su contraseña expira en {0} días',
	'dont reply wraning' => 'ESTE ES UN MENSAJE DE NOTIFICACIÓN. NO RESPONDER A ESTA DIRECCIÓN DE CORREO!',
	'new message posted' => 'Nuevo mensaje "{0}" ha sido publicado',
	'new task' => 'Nueva tarea',
	'new task created' => 'Nueva tarea "{0}" ha sido creada en el espacio "{1}"',
	'view new message' => 'Ver mensaje',
	'view new task' => 'Ver tarea',
	'new comment posted' => 'Un nuevo comentario ha sido publicado en "{0}"',
	'view new comment' => 'Ver el comentario',
	'user created your account' => '{0} ha creado una nueva cuenta para ud.',
	'visit and login' => 'Visite {0} e ingrese con el siguiente nombre de usuario',
	'milestone assigned' => 'Se le ha asignado el hito "{0}"',
	'task assigned' => 'Se le ha asignado la tarea "{0}"',
	'view assigned milestones' => 'Ver el hito',
	'view assigned tasks' => 'Ver la tarea',
	'reply mail' => 'Responder',
	'write mail' => 'Escribir mail',
	'mail to' => 'Para',
	'mail account' => 'Cuenta',
	'mail account desc' => ' Cuenta desde donde se ha enviado el mail',
	'mail subject' => 'Asunto',
	'mail CC' => 'CC',
	'mail CC desc' => ' Los destinatarios copia carbónico recibirán una copia idéntica del mail',
	'mail BCC' => 'CCO',
	'mail BCC desc' => ' Los destinatarios copia carbónico oculto recibirán una copia idéntica del mail, sin que los demás destinatarios lo sepan',
	'mail from' => 'De',
	'mail body' => 'Cuerpo',
	'send mail' => 'Enviar Mail',
	'smtp server' => 'Servidor SMTP',
	'mail account smtp server description' => ' El servidor SMTP es el que va a ser usado para enviar mails',
	'smtp use auth' => 'Autenticación del servidor SMTP',
	'mail account smtp use auth description' => ' La forma en que se va a realizar la autenticación con el servidor SMTP. Por lo general, \'Usar entrante\' es la opción mas correcta.',
	'no smtp auth' => 'No hay autenticación',
	'same as incoming' => 'Usar entrante',
	'smtp specific' => 'Ingrese el nombre de usuario y la contraseña SMTP',
	'smtp username' => 'Nombre de usuario SMTP',
	'mail account smtp username description' => ' Nombre de usuario para el servidor SMTP',
	'smtp password' => 'Contraseña SMTP',
	'mail account smtp password description' => ' Contraseña para el servidor SMTP',
	'smtp port' => 'Puerto de servidor SMTP',
	'mail account smtp port description' => ' Éste es el puerto en el cual el servidor escucha el servicio SMTP. El valor asignado por defecto y el más común es el 25.',
	'outgoing transport type' => 'Conexión segura',
	'mail account outgoing transport type description' => 'Seleccione "ssl" o "tls" para una conexión segura',
	'smtp settings' => 'Ajustes SMTP',
	'forward mail' => 'Reenviar',
	'reply to all mail' => 'Responder a Todos',
	'format plain' => 'Texto Plano',
	'format html' => 'Formatear como HTML',
	'mail options' => 'Opciones',
	'switch format warn' => 'Se perderá el formato actual. Desea continuar?',
	'success mark objects' => 'Mail actualizado',
	'error mark email' => 'Error al actualizar estado de email',
	'draft' => 'Borrador',
	'success save mail' => 'Email salvado',
	'discard' => 'Descartar',
	'mail address' => 'Dirección de email',
	'mail address description' => 'La dirección de correo electrónico es la dirección que otras personas utilizarán para enviarle mensajes',
	'unread emails' => 'Emails no leidos',
	'view due task' => 'Ver tarea a vencer',
	'due task email' => 'La tarea "{0}" vencerá el "{1}" y aún está pendiente',
	'due task' => 'Tarea a vencer',
	'due task reminder' => 'Tarea a vencer',
	'task has been modified' => 'La tarea "{0}" en el espacio "{1}" ha sido modificada.',
	'task modified' => 'Tarea modificada',
	'view task' => 'Ver tarea',
	'original message' => 'Mensaje original',
	'mail sent' => 'Enviado',
	'new notification task' => 'Nueva tarea \'{0}\'',
	'new notification task desc' => 'Una nueva tarea titulada \'{0}\' ha sido agregada por {1}.',
	'new notification event' => 'Nuevo evento \'{0}\'',
	'new notification event desc' => 'Un nuevo evento titulado \'{0}\' ha sido agregada por {1}.',
	'new notification company' => 'Nueva empresa \'{0}\'',
	'new notification company desc' => 'Una nueva empresa de nombre \'{0}\' ha sido agregada por {1}',
	'new notification contact' => 'Nuevo contacto \'{0}\'',
	'new notification contact desc' => 'Un nuevo contacto de nombre \'{0}\' ha sido agregado por {1}',
	'new notification message' => 'Nueva nota \'{0}\'',
	'new notification message desc' => 'Una nueva nota titulada \'{0}\' ha sido agregada por {1}',
	'new notification file' => 'Nuevo archivo \'{0}\'',
	'new notification file desc' => 'Un nuevo archivo de nombre \'{0}\' ha sido agregado por {1}',
	'new notification webpage' => 'Nuevo enlace web \'{0}\'',
	'new notification webpage desc' => 'Un nuevo enlace web \'{0}\' ha sido agregado por {1}',
	'new notification milestone' => 'Nuevo hito \'{0}\'',
	'new notification milestone desc' => 'Un nuevo hito titulado \'{0}\' ha sido agregado {1}',
	'modified notification task' => 'Tarea \'{0}\' ha sido modificada',
	'modified notification task desc' => 'Tarea \'{0}\' ha sido modificada por {1}.',
	'modified notification event' => 'Evento \'{0}\' ha sido modificado',
	'modified notification event desc' => 'Evento \'{0}\' ha sido modificada por {1}.',
	'modified notification company' => 'Empresa \'{0}\' ha sido modificada',
	'modified notification company desc' => 'Empresa \'{0}\' ha sido modificada por {1}.',
	'modified notification contact' => 'Contacto \'{0}\' ha sido modificado',
	'modified notification contact desc' => 'Contacto \'{0}\' ha sido modificado por {1}.',
	'modified notification message' => 'Nota \'{0}\' ha sido modificada',
	'modified notification message desc' => 'Nota \'{0}\' ha sido modificada por {1}.',
	'modified notification file' => 'Archivo \'{0}\' ha sido modificado',
	'modified notification file desc' => 'Archivo \'{0}\' ha sido modificado por {1}.',
	'modified notification webpage' => 'Enlace web \'{0}\' ha sido modificado',
	'modified notification webpage desc' => 'Enlace web \'{0}\' Enlace web a sido modificado por {1}.',
	'modified notification milestone' => 'Hito \'{0}\' ha sido modificado',
	'modified notification milestone desc' => 'Hito \'{0}\' ha sido modificado por {1}.',
	'deleted notification task' => 'Tarea \'{0}\' ha sido enviada a la papelera',
	'deleted notification task desc' => 'Tarea \'{0}\' ha sido enviada a la papelera por {1}.',
	'deleted notification event' => 'Evento \'{0}\' ha sido enviado a la papelera',
	'deleted notification event desc' => 'Evento \'{0}\' ha sido enviado a la papelera por {1}.',
	'deleted notification company' => 'Empresa \'{0}\' ha sido enviada a la papelera',
	'deleted notification company desc' => 'Empresa \'{0}\' ha sido enviada a la papelera por {1}.',
	'deleted notification contact' => 'Contacto \'{0}\' ha sido enviado a la papelera',
	'deleted notification contact desc' => 'Contacto \'{0}\' ha sido enviado a la papelera por {1}.',
	'deleted notification message' => 'Nota \'{0}\' ha sido enviada a la papelera',
	'deleted notification message desc' => 'Nota \'{0}\' ha sido enviada a la papelera por {1}.',
	'deleted notification file' => 'Archivo \'{0}\' ha sido enviado a la papelera',
	'deleted notification file desc' => 'Archivo \'{0}\' ha sido enviado a la papelera por {1}.',
	'deleted notification webpage' => 'Enlace web \'{0}\' ha sido enviado a la papelera',
	'deleted notification webpage desc' => 'Enlace web \'{0}\' ha sido enviado a la papelera {1}.',
	'deleted notification milestone' => 'Hito \'{0}\' ha sido enviado a la papelera',
	'deleted notification milestone desc' => 'Hito \'{0}\' ha sido enviado a la papelera por {1}.',
	'deleted notification email' => 'Correo \'{0}\' ha sido enviado a la papelera',
	'deleted notification email desc' => 'Correo \'{0}\' ha sido enviado a la papelera por {1}.',
	'deleted notification email unclassified desc' => 'Correo \'{0}\' ha sido enviado a la papelera por {1}.',
	'deleted notification emailunclassified desc' => 'Correo \'{0}\' ha sido enviado a la papelera por {1}.',
	'view file' => 'Ver archivo',
	'view message' => 'Ver nota',
	'view comment' => 'Ver comentario',
	'view company' => 'Ver empresa',
	'view contact' => 'Ver contacto',
	'view mail account' => 'Ver cuenta de correo',
	'view email' => 'Ver correo',
	'view emailunclassified' => 'Ver correo',
	'view chart' => 'Ver gráfica',
	'view event' => 'Ver evento',
	'view file_revision' => 'Ver revisión de archivo',
	'view form' => 'Ver formulario',
	'view milestone' => 'Ver hito',
	'view webpage' => 'Ver enlace web',
	'view project' => 'Ver espacio de trabajo',
	'view tag' => 'Ver etiqueta',
	'view template' => 'Ver plantilla',
	'view timeslot' => 'Ver tiempo de trabajo',
	'view user' => 'Ver usuario',
	'closed notification task' => 'La tarea \'{0}\' ha sido completada',
	'closed notification task desc' => 'La tarea \'{0}\' ha sido completada por {1}.',
	'closed notification milestone' => 'El hito \'{0}\' ha sido completado',
	'closed notification milestone desc' => 'El hito \'{0}\' ha sido completado por {1}.',
	'user password reseted desc' => 'Si quiere reestablecer su contraseña de Feng Office siga el siguiente vínculo:',
	'user password reseted desc2' => 'Si usted no ha solicitado reestablecer su contraseña simplemente ignore este correo.',
	'user password reseted username' => 'Usuario: {0}',
	'user password reseted password' => 'Contraseña: {0}',
	'due_date reminder notification task' => 'Recordatorio de tarea con vencimiento',
	'due_date task reminder desc' => 'La tarea "{0}" vence el "{1}" y aún está pendiente',
	'due_date reminder notification milestone' => 'Recordatorio de hito con vencimiento',
	'due_date milestone reminder desc' => 'El hito "{0}" vence el "{1}" y aún está pendiente',
	'start reminder notification event' => 'Recordatorio de evento',
	'start event reminder' => 'Recordatorio de evento',
	'start event reminder desc' => 'El evento "{0}" comienza el "{1}"',
	'mail attachments' => 'Adjuntos',
	'select attachment' => 'Seleccionar y subir el adjunto',
	'attach from workspace' => 'Adjuntar desde espacio de trabajo',
	'attach from file system' => 'Adjuntar desde computadora',
	'new notification comment' => 'Nuevo comentario en \'{0}\'',
	'new notification comment desc' => 'Un nuevo comentario en \'{0}\' fue agregado por {1}.',
	'mail format options' => 'Formato',
	'modified notification email' => 'El correo \'{0}\' ha sido modificado',
	'modified notification email desc' => 'El correo \'{0}\' ha sido modificado por {1}.',
	'subscribed notification task' => 'Suscrito a la Tarea \'{0}\'',
	'subscribed notification task desc' => 'Ha sido suscrito a la Tarea \'{0}\' por {1}.',
	'subscribed notification event' => 'Suscrito al Evento \'{0}\'',
	'subscribed notification event desc' => 'Ha sido suscrito al Evento \'{0}\' por {1}.',
	'subscribed notification company desc' => 'Ha sido suscrito a la Empresa \'{0}\' por {1}.',
	'subscribed notification contact desc' => 'Ha sido suscrito al Contacto \'{0}\' por {1}.',
	'subscribed notification message desc' => 'Ha sido suscrito a la Nota \'{0}\' por {1}.',
	'subscribed notification file desc' => 'Ha sido suscrito al Archivo \'{0}\' por {1}.',
	'subscribed notification webpage desc' => 'Ha sido suscrito al Enlace \'{0}\' por {1}.',
	'subscribed notification milestone desc' => 'Ha sido suscrito al Hito \'{0}\' por {1}.',
	'subscribed notification email desc' => 'Ha sido suscrito al Correo \'{0}\' por {1}.',
	'subscribed notification company' => 'Suscrito a la Empresa \'{0}\'',
	'subscribed notification contact' => 'Suscrito al Contacto \'{0}\'',
	'subscribed notification message' => 'Suscrito a la Nota \'{0}\'',
	'subscribed notification file' => 'Suscrito al Archivo \'{0}\'',
	'subscribed notification webpage' => 'Suscrito al Enlace \'{0}\'',
	'subscribed notification milestone' => 'Suscrito al Hito \'{0}\'',
	'subscribed notification email' => 'Suscrito al Correo \'{0}\'',

	'sent mails sync' => 'Ajustes de sincronización de los emails enviados (sólo para IMAP)',
	'connnection security' => 'Seguridad de la conexión',
	'select folder for outbox' => 'Seleccione su bandeja de salida',
	'sync complete' => 'Sincronización completada',
	'invalid sync settings' => 'Ajustes de sincronización inválidos. No se puede establecer una conexión con el servidor',
	'cant find user' => 'No se puede encontrar al usuario requerido',
	'cant find account' => 'No se puede encontrar la cuenta de correo electrónico requerida',
); ?>

==> fengoffice_2.0.0.zip: fengoffice/language/es_la/emails.php <==
<?php return array(
	'new message' => 'Nueva nota',
	'new comment' => 'Nuevo comentario',
	'your account created' => 'Su nueva cuenta en Feng Office ha sido creada',
	'your password' => 'Contraseña',
	'milestone assigned to you' => 'Se le ha asignado el hito \'{0}\'',
	'task assigned to you' => 'Se le ha asignado una tarea',
        'work estimate title' => 'El tiempo trabajado en la tarea se ha excedido de la estimación',
	'hi john doe' => 'Hola {0}',
	'user password reseted' => 'Su contraseña ha sido cambiada. Su nueva contraseña es \'{0}\'.',
	'password expiration reminder' => 'Recordatorio de expiración de contraseña',
	'password expires days' => 'Su contraseña expira en {0} días',
	'dont reply wraning' => 'ESTE ES UN MENSAJE DE NOTIFICACIÓN. NO RESPONDER A ESTA DIRECCIÓN DE CORREO!',
	'new message posted' => 'Nuevo mensaje "{0}" ha sido publicado',
	'new task' => 'Nueva tarea',
	'new task created' => 'Nueva tarea "{0}" ha sido creada en el espacio "{1}"',
	'view new message' => 'Ver mensaje',
	'view new task' => 'Ver tarea',
	'new comment posted' => 'Un nuevo comentario ha sido publicado en "{0}"',
	'view new comment' => 'Ver el comentario',
	'user created your account' => '{0} ha creado una nueva cuenta para ud.',
	'visit and login' => 'Visite {0} e ingrese con el siguiente nombre de usuario',
	'milestone assigned' => 'Se le ha asignado el hito "{0}"',
	'task assigned' => 'Se le ha asignado la tarea "{0}"',
	'view assigned milestones' => 'Ver el hito',
	'view assigned tasks' => 'Ver la tarea',
	'reply mail' => 'Responder',
	'write mail' => 'Escribir mail',
        'work estimate' => 'El tiempo trabajado en la tarea "{0}" ha superado la estimación.',
	'mail to' => 'Para',
	'mail account' => 'Cuenta',
	'mail account desc' => ' Cuenta desde donde se ha enviado el mail',
	'mail subject' => 'Asunto',
	'mail CC' => 'CC',
	'mail CC desc' => ' Los destinatarios copia carbónico recibirán una copia idéntica del mail',
	'mail BCC' => 'CCO',
	'mail BCC desc' => ' Los destinatarios copia carbónico oculto recibirán una copia idéntica del mail, sin que los demás destinatarios lo sepan',
	'mail from' => 'De',
	'mail body' => 'Cuerpo',
	'send mail' => 'Enviar Mail',
	'smtp server' => 'Servidor SMTP',
	'mail account smtp server description' => ' El servidor SMTP es el que va a ser usado para enviar mails',
	'smtp use auth' => 'Autenticación del servidor SMTP',
	'mail account smtp use auth description' => ' La forma en que se va a realizar la autenticación con el servidor SMTP. Por lo general, \'Usar entrante\' es la opción mas correcta.',
	'no smtp auth' => 'No hay autenticación',
	'same as incoming' => 'Usar entrante',
	'smtp specific' => 'Ingrese el nombre de usuario y la contraseña SMTP',
	'smtp username' => 'Nombre de usuario SMTP',
	'mail account smtp username description' => ' Nombre de usuario para el servidor SMTP',
	'smtp password' => 'Contraseña SMTP',
	'mail account smtp password description' => ' Contraseña para el servidor SMTP',
	'smtp port' => 'Puerto de servidor SMTP',
	'mail account smtp port description' => ' Éste es el puerto en el cual el servidor escucha el servicio SMTP. El valor asignado por defecto y el más común es el 25.',
	'outgoing transport type' => 'Conexión segura',
	'mail account outgoing transport type description' => 'Seleccione "ssl" o "tls" para una conexión segura',
	'smtp settings' => 'Ajustes SMTP',
	'forward mail' => 'Reenviar',
	'reply to all mail' => 'Responder a Todos',
	'format plain' => 'Texto Plano',
	'format html' => 'Formatear como HTML',
	'mail options' => 'Opciones',
	'switch format warn' => 'Se perderá el formato actual. Desea continuar?',
	'success mark objects' => 'Mail actualizado',
	'error mark email' => 'Error al actualizar estado de email',
	'draft' => 'Borrador',
	'success save mail' => 'Email salvado',
	'discard' => 'Descartar',
	'mail address' => 'Dirección de email',
	'mail address description' => 'La dirección de correo electrónico es la dirección que otras personas utilizarán para enviarle mensajes',
	'unread emails' => 'Emails no leidos',
	'view due task' => 'Ver tarea a vencer',
	'due task email' => 'La tarea "{0}" vencerá el "{1}" y aún está pendiente',
	'due task' => 'Tarea a vencer',
	'due task reminder' => 'Tarea a vencer',
	'task has been modified' => 'La tarea "{0}" en el espacio "{1}" ha sido modificada.',
	'task modified' => 'Tarea modificada',
	'view task' => 'Ver tarea',
	'original message' => 'Mensaje original',
	'mail sent' => 'Enviado',
	'new notification task' => 'Nueva tarea \'{0}\'',
	'new notification task desc' => 'Una nueva tarea titulada \'{0}\' ha sido agregada por {1}.',
	'new notification event' => 'Nuevo evento \'{0}\'',
	'new notification event desc' => 'Un nuevo evento titulado \'{0}\' ha sido agregada por {1}.',
	'new notification company' => 'Nueva organización \'{0}\'',
	'new notification company desc' => 'Una nueva organización de nombre \'{0}\' ha sido agregada por {1}',
	'new notification contact' => 'Nueva persona \'{0}\'',
	'new notification contact desc' => 'Una nueva persona de nombre \'{0}\' ha sido agregado por {1}',
	'new notification message' => 'Nueva nota \'{0}\'',
	'new notification message desc' => 'Una nueva nota titulada \'{0}\' ha sido agregada por {1}',
	'new notification file' => 'Nuevo documento \'{0}\'',
	'new notification file desc' => 'Un nuevo documento de nombre \'{0}\' ha sido agregado por {1}',
	'new notification webpage' => 'Nuevo enlace web \'{0}\'',
	'new notification webpage desc' => 'Un nuevo enlace web \'{0}\' ha sido agregado por {1}',
	'new notification weblink' => 'Nuevo enlace web \'{0}\'',
	'new notification weblink desc' => 'Un nuevo enlace web \'{0}\' ha sido agregado por {1}',
	'new notification milestone' => 'Nuevo hito \'{0}\'',
	'new notification milestone desc' => 'Un nuevo hito titulado \'{0}\' ha sido agregado {1}',
	'modified notification task' => 'Tarea \'{0}\' ha sido modificada',
	'modified notification task desc' => 'Tarea \'{0}\' ha sido modificada por {1}.',
	'modified notification event' => 'Evento \'{0}\' ha sido modificado',
	'modified notification event desc' => 'Evento \'{0}\' ha sido modificada por {1}.',
	'modified notification company' => 'Organización \'{0}\' ha sido modificada',
	'modified notification company desc' => 'Organización \'{0}\' ha sido modificada por {1}.',
	'modified notification contact' => 'La Persona \'{0}\' ha sido modificado',
	'modified notification contact desc' => 'La Persona \'{0}\' ha sido modificado por {1}.',
	'modified notification message' => 'Nota \'{0}\' ha sido modificada',
	'modified notification message desc' => 'Nota \'{0}\' ha sido modificada por {1}.',
	'modified notification file' => 'Documento \'{0}\' ha sido modificado',
	'modified notification file desc' => 'Documento \'{0}\' ha sido modificado por {1}.',
	'modified notification weblink' => 'Enlace web \'{0}\' ha sido modificado',
	'modified notification weblink desc' => 'Enlace web \'{0}\' Enlace web a sido modificado por {1}.',
	'modified notification webpage' => 'Enlace web \'{0}\' ha sido modificado',
	'modified notification webpage desc' => 'Enlace web \'{0}\' Enlace web a sido modificado por {1}.',
	'modified notification milestone' => 'Hito \'{0}\' ha sido modificado',
	'modified notification milestone desc' => 'Hito \'{0}\' ha sido modificado por {1}.',
	'deleted notification task' => 'Tarea \'{0}\' ha sido enviada a la papelera',
	'deleted notification task desc' => 'Tarea \'{0}\' ha sido enviada a la papelera por {1}.',
	'deleted notification event' => 'Evento \'{0}\' ha sido enviado a la papelera',
	'deleted notification event desc' => 'Evento \'{0}\' ha sido enviado a la papelera por {1}.',
	'deleted notification company' => 'Organización \'{0}\' ha sido enviada a la papelera',
	'deleted notification company desc' => 'Organización \'{0}\' ha sido enviada a la papelera por {1}.',
	'deleted notification contact' => 'La Persona \'{0}\' ha sido enviado a la papelera',
	'deleted notification contact desc' => 'La Persona \'{0}\' ha sido enviado a la papelera por {1}.',
	'deleted notification message' => 'Nota \'{0}\' ha sido enviada a la papelera',
	'deleted notification message desc' => 'Nota \'{0}\' ha sido enviada a la papelera por {1}.',
	'deleted notification file' => 'Documento \'{0}\' ha sido enviado a la papelera',
	'deleted notification file desc' => 'Documento \'{0}\' ha sido enviado a la papelera por {1}.',
	'deleted notification weblink' => 'Enlace web \'{0}\' ha sido enviado a la papelera',
	'deleted notification weblink desc' => 'Enlace web \'{0}\' ha sido enviado a la papelera {1}.',
	'deleted notification webpage' => 'Enlace web \'{0}\' ha sido enviado a la papelera',
	'deleted notification webpage desc' => 'Enlace web \'{0}\' ha sido enviado a la papelera {1}.',
	'deleted notification milestone' => 'Hito \'{0}\' ha sido enviado a la papelera',
	'deleted notification milestone desc' => 'Hito \'{0}\' ha sido enviado a la papelera por {1}.',
	'deleted notification email' => 'Correo \'{0}\' ha sido enviado a la papelera',
	'deleted notification email desc' => 'Correo \'{0}\' ha sido enviado a la papelera por {1}.',
	'view file' => 'Ver documento',
	'view message' => 'Ver nota',
	'view comment' => 'Ver comentario',
	'view company' => 'Ver organización',
	'view contact' => 'Ver persona',
	'view mail account' => 'Ver cuenta de correo',
	'view email' => 'Ver correo',
	'view emailunclassified' => 'Ver correo',
	'view chart' => 'Ver gráfica',
	'view event' => 'Ver evento',
	'view file_revision' => 'Ver revisión de documento',
	'view form' => 'Ver formulario',
	'view milestone' => 'Ver hito',
	'view webpage' => 'Ver enlace web',
	'view project' => 'Ver espacio de trabajo',
	'view tag' => 'Ver etiqueta',
	'view template' => 'Ver plantilla',
	'view timeslot' => 'Ver tiempo de trabajo',
	'view user' => 'Ver usuario',
	'closed notification task' => 'La tarea \'{0}\' ha sido completada',
	'closed notification task desc' => 'La tarea \'{0}\' ha sido completada por {1}.',
	'closed notification milestone' => 'El hito \'{0}\' ha sido completado',
	'closed notification milestone desc' => 'El hito \'{0}\' ha sido completado por {1}.',
	'user password reseted desc' => 'Ha solicitado reestablecer su contraseña. Si quiere reestablecer su contraseña siga el siguiente vínculo. Si usted no ha solicitado reestablecer su contraseña simplemente ignore este correo.',
	'user password reseted username' => 'Usuario: {0}',
	'user password reseted password' => 'Contraseña: {0}',
	'due_date reminder notification task' => 'Recordatorio de tarea con vencimiento',
	'due_date task reminder desc' => 'La tarea "{0}" vence el "{1}" y aún está pendiente',
	'due_date reminder notification milestone' => 'Recordatorio de hito con vencimiento',
	'due_date milestone reminder desc' => 'El hito "{0}" vence el "{1}" y aún está pendiente',
	'start reminder notification event' => 'Recordatorio de evento',
	'start event reminder' => 'Recordatorio de evento',
	'start event reminder desc' => 'El evento "{0}" comienza el "{1}"',
	'mail attachments' => 'Adjuntos',
	'select attachment' => 'Seleccionar y subir el adjunto',
	'attach from workspace' => 'Adjuntar desde espacio de trabajo',
    'attach from fengoffice' => 'Adjuntar desde Feng Office',
	'attach from file system' => 'Adjuntar desde computadora',
	'new notification comment' => 'Nuevo comentario en \'{0}\'',
	'new notification comment desc' => 'Un nuevo comentario en \'{0}\' fue agregado por {1}.',
	'modified notification comment' => 'Un comentario en \'{0}\' ha sido modificado',
	'modified notification comment desc' => 'Un comentario en \'{0}\' ha sido modificado por {1}.',
	'deleted notification comment' => 'Un comentario en \'{0}\' ha sido enviado a la papelera',
	'deleted notification comment desc' => 'Un comentario en \'{0}\' ha sido enviado a la papelera por {1}.',
	'mail format options' => 'Formato',
	'modified notification email' => 'El correo \'{0}\' ha sido modificado',
	'modified notification email desc' => 'El correo \'{0}\' ha sido modificado por {1}.',
	'subscribed notification task' => 'Suscrito a la Tarea \'{0}\'',
	'subscribed notification task desc' => 'Ha sido suscrito a la Tarea \'{0}\' por {1}.',
	'subscribed notification event' => 'Suscrito al Evento \'{0}\'',
	'subscribed notification event desc' => 'Ha sido suscrito al Evento \'{0}\' por {1}.',
	'subscribed notification company desc' => 'Ha sido suscrito a la Organización \'{0}\' por {1}.',
	'subscribed notification contact desc' => 'Ha sido suscrito a la Persona \'{0}\' por {1}.',
	'subscribed notification message desc' => 'Ha sido suscrito a la Nota \'{0}\' por {1}.',
	'subscribed notification file desc' => 'Ha sido suscrito al Documento \'{0}\' por {1}.',
	'subscribed notification webpage desc' => 'Ha sido suscrito al Enlace \'{0}\' por {1}.',
	'subscribed notification weblink desc' => 'Ha sido suscrito al Enlace \'{0}\' por {1}.',
	'subscribed notification milestone desc' => 'Ha sido suscrito al Hito \'{0}\' por {1}.',
	'subscribed notification email desc' => 'Ha sido suscrito al Correo \'{0}\' por {1}.',
	'subscribed notification company' => 'Suscrito a la Organización \'{0}\'',
	'subscribed notification contact' => 'Suscrito a la Persona \'{0}\'',
	'subscribed notification message' => 'Suscrito a la Nota \'{0}\'',
	'subscribed notification file' => 'Suscrito al Documento \'{0}\'',
	'subscribed notification webpage' => 'Suscrito al Enlace \'{0}\'',
	'subscribed notification weblink' => 'Suscrito al Enlace \'{0}\'',
	'subscribed notification milestone' => 'Suscrito al Hito \'{0}\'',
	'subscribed notification email' => 'Suscrito al Correo \'{0}\'',

	'sent mails sync' => 'Ajustes de sincronización de los emails enviados (sólo para IMAP)',
	'connnection security' => 'Seguridad de la conexión',
	'select folder for outbox' => 'Seleccione su bandeja de salida',
	'sync complete' => 'Sincronización completada',
	'invalid sync settings' => 'Ajustes de sincronización inválidos. No se puede establecer una conexión con el servidor',
	'cant find user' => 'No se puede encontrar al usuario requerido',
	'cant find account' => 'No se puede encontrar la cuenta de correo electrónico requerida',
); ?>
